@@ -5,11 +5,11 @@ import pandas as pd
 from builtins import object
 
 
-def _check_ctx(obj_type):
-    from transcriptic import ctx
-    if not ctx:
+def _check_api(obj_type):
+    from transcriptic import api
+    if not api:
         raise RuntimeError("You have to be logged in to be able to create %s objects" % obj_type)
-    return ctx
+    return api
 
 
 class ProtocolPreview(object):
@@ -32,7 +32,7 @@ class _BaseObject(object):
             self.attributes = attributes
         else:
             if not connection:
-                self.connection = _check_ctx(obj_type)
+                self.connection = _check_api(obj_type)
             else:
                 self.connection = connection
             (self.id, self.name) = self.load_object(obj_type, obj_id)
@@ -74,6 +74,7 @@ class Project(_BaseObject):
     Example Usage:
 
     .. code-block:: python
+
         myProject = Project("My Project")
         projectRuns = myProject.runs()
         myRunId = projectRuns.query("title == 'myRun'").id.item()
@@ -396,10 +397,9 @@ class Container(_BaseObject):
         connection: Optional[transcriptic.config.Connection]
             Connection context. The default context object will be used unless explicitly provided
         """
-        # super(Container, self).__init__(container_id, attributes, connection)
+        super(Container, self).__init__('container', container_id, attributes, connection)
         # TODO: Unify container "label" with name, add Containers route
         self.id = container_id
-        self.attributes = attributes
         self.name = self.attributes["label"]
 
         self.aliquots = self.attributes["aliquots"]
